@@ -18,6 +18,7 @@ package relex;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.UUID;
 
 import relex.feature.Atom;
 import relex.feature.FeatureForeach;
@@ -243,6 +244,28 @@ public class ParsedSentence extends Atom implements Serializable
 		return cb.found;
 	}
 
+	/**
+	 * assign_id -- Add UUID tags to all word nodes in the parse. 
+	 * These UUID tags are used by opencog, and by other parts
+	 * (e.g. the anaphora resolution code) to uniquely identify
+	 * individual word instances across multiple parses of 
+	 * multiple sentences of multiple documents or conversations.
+	 */
+	public void assign_id()
+	{
+		FeatureNode fn = getLeft();
+		fn.add("uuid", "LEFT-WALL@" + getIDString());
+		fn = fn.get("NEXT");
+		while (fn != null)
+		{
+			String word = fn.get("orig_str").getValue();
+			UUID guid = UUID.randomUUID();
+			String guid_word = word + "@" + guid;
+			fn.add("uuid", guid_word);
+			fn = fn.get("NEXT");
+		}
+	}
+
 	/* -------------------------------------------------------------------- */
 	/* Various different views of the parsed sentence */
 
@@ -296,7 +319,7 @@ public class ParsedSentence extends Atom implements Serializable
 	{
 		return RelationForeach.foreach(getLeft(), cb);
 	}
-	
+
 	public Boolean foreach(FeatureNodeCallback cb)
 	{
 		return RelationForeach.foreach(getLeft(), cb);
@@ -352,7 +375,7 @@ public class ParsedSentence extends Atom implements Serializable
 
 	/**
 	 * Perform a crude parse-ranking based on Link-grammar output.
-	 * The ranking will be stored as the "confidence" of the 
+	 * The ranking will be stored as the "confidence" of the
 	 * TruthValue associated with this parse.
 	 *
 	 * @returns the score that was assigned.
@@ -383,9 +406,9 @@ public class ParsedSentence extends Atom implements Serializable
 		stv.setConfidence(weight);
 		return weight;
 	}
-	
+
 	/**
-	 * Take the current parse confidence, and rescale it by the 
+	 * Take the current parse confidence, and rescale it by the
 	 * indicated amount.  The method simpleRankParse() must have
 	 * been previously called to perform the initial ranking.
 	 */
@@ -420,5 +443,5 @@ public class ParsedSentence extends Atom implements Serializable
 		else
 			return original.equals(p.original) && this.leafConstituents.equals(p.leafConstituents);
 	}
-	
+
 } // end ParsedSentence
