@@ -419,7 +419,10 @@ public class RelationExtractor
 		re.setMaxParseSeconds(maxParseSeconds);
 		System.out.println("; Version: " + re.getVersion());
 
-		if (commandMap.get("-a") != null)
+		// Don't run anaphora if -o is set, this will be done in a
+		// distinct stage that wipes out the first run.
+		if ((commandMap.get("-a") != null) &&
+		    (commandMap.get("-o") == null))
 		{
 			re.do_anaphora_resolution = true;
 		}
@@ -442,10 +445,35 @@ public class RelationExtractor
 
 		ParseView ceregoView = new ParseView();
 		OpenCogScheme opencog = null;
-		if (commandMap.get("-o") != null) opencog = new OpenCogScheme();
+		if (commandMap.get("-o") != null)
+		{
+			opencog = new OpenCogScheme();
+			if (commandMap.get("-l") != null)
+			{
+				opencog.setShowLinkage(true);
+			}
+			opencog.setShowRelex(true);
+			if (commandMap.get("-q") != null)
+			{
+				opencog.setShowRelex(false);
+			}
+			if (commandMap.get("-f") != null)
+			{
+				opencog.setShowFrames(true);
+			}
+			if (commandMap.get("-a") != null)
+			{
+				opencog.setShowAnaphora(true);
+			}
+		}
 
+		// Print normal frames, but only if -o has not been invoked.
 		Frame frame = null;
-		if (commandMap.get("-f") != null) frame = new Frame();
+		if ((commandMap.get("-f") != null) &&
+		    (commandMap.get("-o") == null))
+		{
+			frame = new Frame();
+		}
 
 		int sentence_count = 0;
 		boolean more_input = true;
@@ -517,6 +545,7 @@ public class RelationExtractor
 					if (commandMap.get("-r") != null)
 					{
 						System.out.println("\n====\n");
+						System.out.println("Dependency graph:\n");
 						System.out.println(RawView.printZHeads(parse.getLeft()));
 						System.out.println("\n======\n");
 					}
@@ -558,6 +587,7 @@ public class RelationExtractor
 					    (commandMap.get("-o") == null))
 					{
 						System.out.println("\n======\n");
+						System.out.println("Dependency relations:\n");
 						System.out.println(SimpleView.printRelations(parse));
 						System.out.println("\n======\n");
 					}
@@ -602,7 +632,8 @@ public class RelationExtractor
 						System.out.println(ceregoView.printCerego());
 						System.out.println("\n<!-- ======\n");
 					}
-					if (commandMap.get("-f") != null)
+					if ((commandMap.get("-f") != null) &&
+					    (commandMap.get("-o") == null))
 					{
 						re.starttime = System.currentTimeMillis();
 						String fin = SimpleView.printRelationsAlt(parse);
@@ -631,7 +662,8 @@ public class RelationExtractor
 					             ranker.toString());
 				}
 
-				if (re.do_anaphora_resolution)
+				if (re.do_anaphora_resolution &&
+				    (commandMap.get("-o") == null))
 				{
 					System.out.println("\nAntecedent candidates:\n"
 					                   + re.antecedents.toString());
