@@ -24,10 +24,11 @@ import java.io.InputStreamReader;
 import java.io.BufferedReader;
 import java.net.ServerSocket;
 import java.net.Socket;
-// import relex.output.SimpleView;
-// import relex.frame.Frame;
+import relex.output.SimpleView;
+import relex.frame.Frame;
 import relex.output.OpenCogScheme;
 
+
 /**
  * The Server class provides a very simple socket-based parse server.
  * It will listen for plain-text input sentences on port 4444, and will
@@ -49,11 +50,84 @@ public class Server
 
 	public static void main(String[] args)
 	{
+		boolean frame_on = false;
+		boolean relex_on = false;
+		boolean link_on = false;
+		boolean anaphora_on = false;
+		boolean verbose = false;
+		String usageString = "RelEx server (designed for OpenCog interaction).\n" +
+			" --relex    \t Output RelEx relations (default)\n" +
+			" --link     \t Output Link Grammar Linkages\n" +
+			" --frame    \t Output Semantic Frames\n" +
+			" --anaphora \t Output anaphore references\n" +
+			" --verbose  \t Print parse/frame output to server stdout.\n";
+
+		for (int i = 0; i < args.length; i++)
+		{
+			if (args[i].equals("--anaphora"))
+			{
+				anaphora_on = true;
+			}
+			else if (args[i].equals("--frame"))
+			{
+				frame_on = true;
+			}
+			else if (args[i].equals("--help") )
+			{
+				System.out.println(usageString);
+				System.exit(0);
+			}
+			else if (args[i].equals("--link"))
+			{
+				link_on = true;
+			}
+			else if (args[i].equals("--relex"))
+			{
+				relex_on = true;
+			}
+			else if (args[i].equals("--verbose") )
+			{
+				System.err.println("Info: Verbose server mode set.");
+				verbose = true;
+			}
+			else
+			{
+				System.err.println("Error: Unknown option " + args[i]);
+				System.err.println(usageString);
+				System.exit(1);
+			}
+		}
 		RelationExtractor r = new RelationExtractor(false);
-		// Frame frame = new Frame();
 		OpenCogScheme opencog = new OpenCogScheme();
 		Server s = new Server();
 		ServerSocket listen_sock = null;
+
+		if (!frame_on && !relex_on && !link_on)
+		{
+			// By default just export RelEx output, not frames
+			relex_on = true;
+		}
+		if (anaphora_on)
+		{
+			System.err.println("Info: Anaphora output on.");
+			opencog.setShowAnaphora(anaphora_on);
+		}
+		if (frame_on)
+		{
+			System.err.println("Info: Frame output on.");
+			opencog.setShowFrames(frame_on);
+		}
+		if (link_on)
+		{
+			System.err.println("Info: Link grammar output on.");
+			opencog.setShowLinkage(link_on);
+		}
+		if (relex_on)
+		{
+			System.err.println("Info: RelEx output on.");
+			opencog.setShowRelex(relex_on);
+		}
+
 		try {
 			listen_sock = new ServerSocket(s.listen_port);
 		} catch (IOException e) {
@@ -93,16 +167,19 @@ public class Server
 				}
 				ParsedSentence parse = sntc.getParses().get(0);
 
-				/*
 				out.println(parse.getPhraseString());
 
-				String fin = SimpleView.printRelationsAlt(p);
-				String[] fout = frame.process(fin);
-				for (int i=0; i < fout.length; i++) {
-					out.println(fout[i]);
+				if (verbose) {
+					String fin = SimpleView.printRelationsAlt(parse);
+					System.out.print(fin);
+					if (frame_on) {
+						Frame frame = new Frame();
+						String[] fout = frame.process(fin);
+						for (int i=0; i < fout.length; i++) {
+							System.out.println(fout[i]);
+						}
+					}
 				}
-				*/
-					
 				opencog.setParse(parse);
 				out.println(opencog.toString());
 
