@@ -1,6 +1,5 @@
-package relex.algs;
 /*
- * Copyright 2008 Novamente LLC
+ * Copyright 2008,2009 Novamente LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +14,8 @@ package relex.algs;
  * limitations under the License.
  */
 
+package relex.algs;
+
 import java.util.Iterator;
 import java.util.Map;
 
@@ -55,12 +56,9 @@ public class PrepositionLinkAlg extends TemplateMatchingAlg
 		}
 	}
 
-	protected void applyTo(FeatureNode node, RelexContext context)
+	protected void applyTo(FeatureNode node, RelexContext context,
+	                       Map<String,FeatureNode> vars)
 	{
-		Map<String, FeatureNode> vars = getTemplate().match(node); 
-		if (vars == null)
-			return;
-
 		FeatureNode modified = getTemplate().val("modified", vars);
 		FeatureNode prepStringValue = getTemplate().val("prep", vars);
 		FeatureNode prep_obj = getTemplate().val("prep_obj", vars);
