@@ -1,5 +1,5 @@
 /*
- * Copyright 2008 Novamente LLC
+ * Copyright 2008,2009 Novamente LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,8 +20,8 @@ package relex.algs;
  * This algorithm combines sequences of words which should be a single word 
  * (proper names, and idioms like "at hand")
  */
-import java.util.Map;
 import java.util.regex.Pattern;
+import java.util.Map;
 
 import relex.concurrent.RelexContext;
 import relex.feature.FeatureNode;
@@ -102,13 +102,10 @@ public class WordSequenceCombineAlg extends TemplateMatchingAlg
 		                     rightNode, labelRegex, shouldEraseStrAndRef);
 	}
 
-	protected void applyTo(FeatureNode node, RelexContext context)
+	protected void applyTo(FeatureNode node, RelexContext context,
+	                       Map<String,FeatureNode> vars)
 	{
-		Map<String, FeatureNode> vars = getTemplate().match(node); 
-		if (vars == null)
-			return;
 		FeatureNode rightNode = getTemplate().val("right", vars);
-		
 		if (rightNode != LinkView.getRight(node))
 			throw new RuntimeException("variable 'right' is not properly assigned");
 		if (!isRightMost(rightNode, allLabelRegex))
@@ -133,6 +130,7 @@ public class WordSequenceCombineAlg extends TemplateMatchingAlg
 		// rightNode.set("orig_str", new FeatureNode(bigNameWithSpaces));
 		rightNode.set("collocation_end", rightNode);
 		rightNode.set("collocation_start", leftNode);
+		// rightNode.set("start_char", leftNode.get("start_char"));
 		rightNode.get("start_char").setValue(leftNode.get("start_char").getValue());
 
 		// Use morphology on the right node, just in case.
