@@ -20,6 +20,9 @@ import java.util.ArrayList;
 import java.util.Iterator;
 import relex.Sentence;
 import relex.ParsedSentence;
+import relex.anaphora.history.SentenceHistory;
+import relex.anaphora.history.SentenceHistoryFactory;
+import relex.anaphora.history.SentenceHistoryFactory.HistoryEnum;
 import relex.feature.FeatureNode;
 import relex.tree.PhraseTree;
 
@@ -36,19 +39,15 @@ import relex.tree.PhraseTree;
 public class Hobbs
 {
 	public static final int DEBUG = 0;
-	
+
 	// Buffer of sentences previously seen.
-	// XXX replace by Document
-	private ArrayList<Sentence> sentences;
+	private SentenceHistory history;
 
 	// Where anaphora/antecedent collections are kept.
 	Antecedents antecedents;
 
-	// The max number of sentences to keep in the history buffer.
-	static int max_sentences = 20;
-
 	// The max number of antecedent proposals to make.
-	static int max_proposals = 10;
+	static int max_proposals = 20;
 
 	// Fidelity to the original Hobbs algo:
 	// Set to false to stick closer to the original paper.
@@ -57,24 +56,29 @@ public class Hobbs
 	// Pointer to anaphore of the currently-parsed sentence.
 	private PhraseTree anaphore;
 	private int num_proposals;
-	private static Integer ana_id = 1;
+
+	// The ParsedSentence being evaluated
+	private ParsedSentence currentParsedSentence = null;
 
 	protected Hobbs() {}
 
 	public Hobbs(Antecedents ant)
 	{
-		sentences = new ArrayList<Sentence>();
 		antecedents = ant;
 		anaphore = null;
 		num_proposals = 0;
+		// Default history
+		history = SentenceHistoryFactory.create(HistoryEnum.DEFAULT);
 	}
 
 	public void addParse(Sentence sntc)
 	{
-		// Add at the head of the list
-		sentences.add(0, sntc);
-		int sz = sentences.size();
-		if (sz > max_sentences) sentences.remove(max_sentences);
+		history.addSentence(sntc);
+	}
+
+	public void setHistory(SentenceHistory sh)
+	{
+		history = sh;
 	}
 
 	public void resolve(Sentence sntc)
@@ -90,43 +94,20 @@ public class Hobbs
 
 	 	for (PhraseTree prn : prlist)
 		{
-			relabel(prn);
+	 		// Set the currentParsedSentence to get the word from its word_list
+	 		currentParsedSentence = ps;
 			scan(prn);
 		}
 	}
 
 	/* ---------------------------------------------------------- */
-	/**
-	 * Give the string names of the prnouns unique ids.
-	 *
-	 * This is a strange hack used for relationship printing.
-	 * Each pronoun in each sentence potentially refers to
-	 * a different thing, and so, we want too make sure
-	 * each pronoun gets a unique id. Now, I could put
-	 * these unique id's into thier own node, but the
-	 * relation printing code is ignorant of that. So
-	 * we'll just brute-force change the string name.
-	 *
-	 * This idea is subject to redesign/rethinking.
-	 */
-	private void relabel(PhraseTree ana)
-	{
-		FeatureNode name = ana.get("str");
-		if (name == null)
-		{
-			System.err.println(
-			     "Error: can't find str featurenode during anaphora resolution");
-			return;
-		}
-		String str = name.getValue();
-		str += "_" + ana_id;
-		name.setValue(str);
 
-		ana_id ++;
-	}
+	// Return a string that uniquely labels this word instance.
+	// Every word/phrase *must* get its own, unique ID.
+	// Seems simplest ot use the pre-assigned UUID's for this purpose.
 	private String getlabel(PhraseTree ana)
 	{
-		FeatureNode name = ana.get("str");
+		FeatureNode name = ana.get("uuid");
 		return name.getValue();
 	}
 
@@ -164,6 +145,7 @@ public class Hobbs
 			// "NP". So don't print any warnings, but also, don't do anything.
 			return;
 		}
+
 		anaphore = pt; // The "dominating NP" of the pronoun
 		num_proposals = 0;
 
@@ -203,6 +185,7 @@ public class Hobbs
 		}
 
 		// Step 4b: Iterate over earlier sentences.
+		ArrayList<Sentence> sentences = history.getSentenceList();
 		for (int i=1; i< sentences.size(); i++)
 		{
 			if (num_proposals > max_proposals) break;
@@ -213,8 +196,8 @@ public class Hobbs
 			if (sntc.getParses().size() == 0) continue;
 
 			// XXX ignore all but the first parse right now
-			ParsedSentence ps = sntc.getParses().get(0);
-			PhraseTree head = ps.getPhraseTree();
+			currentParsedSentence = sntc.getParses().get(0);
+			PhraseTree head = currentParsedSentence.getPhraseTree();
 			StepFour(head);
 		}
 	}
@@ -408,12 +391,12 @@ public class Hobbs
 						antecedents.add(anaphore, pt);
 						if (DEBUG > 0)
 						{
-							System.out.println("Found antecedent "
-						                 +  pt.toString()
-						                 + " to pronoun "
-						                 + anaphore.toString());
+							System.err.println("Found antecedent "
+							                 +  pt.toString()
+							                 + " to pronoun "
+							                 + anaphore.toString());
 
-							System.out.println("Current list:\n"
+							System.err.println("Current list:\n"
 							              + antecedents.toString(anaphore));
 						}
 						if (stop_at_np) pt.setMark(marker);
@@ -445,7 +428,6 @@ public class Hobbs
 			if (pt.contains(path_stopper)) break;
 		}
 	}
-
 } // end Hobbs
 
 /* ==================== END OF FILE ================== */
