@@ -296,20 +296,20 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		throwIfNoFN(ths);
 
 		// Inflections may be one letter, or they may be longer.
-		// Just right now, they happen to be only one letter, 
-		// but this will soon change.
+		// Link-grammar calls these "word subscripts"; perhaps we should
+		// stop mis-using the term "inflection" here ... 
 		int len = wordString.length();
-		if ((2 < len) && (wordString.indexOf('.') == len -2))
+		int dot = wordString.lastIndexOf('.');
+		if ((2 < len) && (dot == len-2))
 		{
 			char inflection = wordString.charAt(len-1);
-			wordString = wordString.substring(0, len-2);
 			switch(inflection)
 			{
 				case 'a': setPOS(ths, "adj"); break;
 				case 'b': setPOS(ths, "noun"); break; // male or female
 				case 'e': setPOS(ths, "adv"); break; // adverbs alternate
 				case 'f': setPOS(ths, "noun"); break; // female
-				case 'g': setPOS(ths, "verb"); break; // gerund
+				case 'g': setPOS(ths, "noun"); break; // gerund -- noun or verb ??
 				case 'l': setPOS(ths, "noun"); break; // location
 				case 'm': setPOS(ths, "noun"); break; // male
 				case 'n': setPOS(ths, "noun"); break;
@@ -347,7 +347,27 @@ public class LinkableView extends View // implements TreeNode , LinkNode
 		{
 			setPOS(ths, POS_WORD);
 		}
-		ths.set(WORD_STRING_FEATURE_NAME, new FeatureNode(wordString));
+		if ((0 < dot) && (dot != len-1))
+		{
+			wordString = wordString.substring(0, dot);
+		}
+
+		// Words that are unknown to link grammar, or run through its
+		// spell-guesser, or otherwise guessed at, will end with either a
+		// [?] or [!] or [~]. Strip this out, as it messes with stuff.
+		if (wordString.endsWith("[?]") ||
+		    wordString.endsWith("[!]") ||
+		    wordString.endsWith("[~]"))
+		{
+			len = wordString.length(); // recompute length, due to above dots.
+			wordString = wordString.substring(0,len-3);
+		}
+
+		FeatureNode f = new FeatureNode(wordString);
+		ths.set(WORD_STRING_FEATURE_NAME, f);
+
+		// The MorphyAlg will modify the above, so make a copy of the original.
+		ths.set(ORIG_WORD_STRING_FEATURE_NAME, f);
 	}
 
 	public String getWordString() {
