@@ -31,9 +31,9 @@ public class OpenCogSchemeFrame
 	// The sentence being examined.
 	private ParsedSentence sent;
 
-	// The id_map, previously created, for OpenCog id's
-	private HashMap<FeatureNode,String> id_map = null;
-
+	// The id_map translates UUID back to words.
+	private HashMap<String,String> uuid_to_root_map = null;
+	
 	private Frame frame;
 
 	/* ------------------------------------------------------------- */
@@ -42,25 +42,31 @@ public class OpenCogSchemeFrame
 	public OpenCogSchemeFrame()
 	{
 		sent = null;
-		id_map = null;
 		frame = new Frame();
 	}
 
-	public void setParse(ParsedSentence s, HashMap<FeatureNode,String> im)
+	public void setParse(ParsedSentence s)
 	{
 		sent = s;
-		id_map = im;
+		uuid_to_root_map = new HashMap<String,String>();
+		FeatureNode fn = s.getLeft();
+		while (fn != null)
+		{
+			String lemma = fn.get("str").getValue();
+			String uuid = fn.get("uuid").getValue();
+			uuid_to_root_map.put(uuid, lemma);
+			fn = fn.get("NEXT");
+		}
 	}
-
+		
 	/* ------------------------------------------------------------- */
-
+	
 	private String printFrames()
 	{
 		String ret = "";
-		String fin = SimpleView.printRelationsAlt(sent, id_map);
-		fin = fin.replaceAll("@[^,\\)]*","");
-		String[] fms = frame.process(fin);
-
+		String fin = SimpleView.printRelationsUUID(sent);
+		String[] fms = frame.process(fin,uuid_to_root_map);
+		
 		for (String fm : fms) 
 		{
 			// First, parse out the framenet string 
@@ -98,10 +104,10 @@ public class OpenCogSchemeFrame
 			{
 				cpt2 = cpt1.substring(comma+1);
 				cpt1 = cpt1.substring(0, comma);
+				//System.err.println("cpt1: " + cpt1);
+				//System.err.println("cpt2: " + cpt2);
 			}
 			if (cpt1 == null) continue;
-			// cpt1 = id_map.get(cpt1);
-			if (cpt1 == null) continue;
 
 			// Is cpt1 a "DefinedLinguisticConceptNode"?
 			Boolean cpt1_is_ling = false;
@@ -110,27 +116,40 @@ public class OpenCogSchemeFrame
 
 			if (cpt2 != null)
 			{
-				// cpt2 = id_map.get(cpt2);
-				if (cpt2 == null) continue;
 				if (cpt2.charAt(0) == '#') cpt2_is_ling = true;
 			}
 
+			// Are cpt1 and 2 true WordInstances, or concepts?
+			Boolean cpt1_is_word = false;
+			Boolean cpt2_is_word = false;
+			if (-1 < cpt1.indexOf('@')) cpt1_is_word = true;
+			if ((cpt2 != null) && (-1 < cpt2.indexOf('@'))) cpt2_is_word = true;
+
 			// Link together.
-			ret += "(FrameElementLink\n" +
+			ret += "(FrameElementLink (stv 1 1)\n" +
 			       "   (DefinedFrameNode \"#" + frm + "\")\n" +
 			       "   (DefinedFrameElementNode \"#" +
                      frm + ":" + felt + "\")\n)\n";
 
 			// Now, for the specific mappings
-			ret += "(InheritanceLink\n";
+			ret += "(InheritanceLink ";
+
+			// Assign a nominal truth value
+			if (cpt1_is_word) ret += "(stv 1 0.2)\n";
+			else ret += "(stv 1 1)\n";
+
 			if (cpt1_is_ling)
 			{
-				ret += "   (DefinedLinguisticConceptNode \"" + 
+				ret += "   (DefinedLinguisticConceptNode \"#" + 
 				            cpt1 + "\")\n";
 			}
+			else if (cpt1_is_word)
+			{
+				ret += "   (WordInstanceNode \"" + cpt1 + "\")\n";
+			}
 			else
 			{
-				ret += "   (WordInstanceNode \"" + cpt1 + "\")\n";
+				ret += "   (ConceptNode \"#" + cpt1 + "\")\n";
 			}
 			ret += "   (DefinedFrameNode \"#" + frm + "\")\n)\n";
 
@@ -138,7 +157,8 @@ public class OpenCogSchemeFrame
 			if (cpt2 == null) continue;
 
 			// Finally link the frame element
-			ret += "(EvaluationLink\n";
+			// Assign some bogus place-holder truth value.
+			ret += "(EvaluationLink (stv 1 0.2)\n";
 			ret += "   (DefinedFrameElementNode \"#" +
                      frm + ":" + felt + "\")\n";
 
@@ -146,21 +166,29 @@ public class OpenCogSchemeFrame
 			ret += "   (ListLink\n";
 			if (cpt1_is_ling)
 			{
-				ret += "      (DefinedLinguisticConceptNode \"" + 
+				ret += "      (DefinedLinguisticConceptNode \"#" + 
 				            cpt1 + "\")\n";
 			}
-			else
+			else if (cpt1_is_word)
 			{
 				ret += "      (WordInstanceNode \"" + cpt1 + "\")\n";
 			}
+			else
+			{
+				ret += "      (ConceptNode \"#" + cpt1 + "\")\n";
+			}
 			if (cpt2_is_ling)
 			{
-				ret += "      (DefinedLinguisticConceptNode \"" + 
+				ret += "      (DefinedLinguisticConceptNode \"#" + 
 				            cpt2 + "\")\n";
 			}
+			else if (cpt2_is_word)
+			{
+				ret += "      (WordInstanceNode \"" + cpt2 + "\")\n";
+			}
 			else
 			{
-				ret += "      (WordInstanceNode \"" + cpt2 + "\")\n";
+				ret += "      (ConceptNode \"#" + cpt2 + "\")\n";
 			}
 			ret += "   )\n)\n";
 		}
