@@ -16,9 +16,6 @@
 
 package relex.output;
 
-import java.util.ArrayList;
-import java.util.HashMap;
-
 import relex.ParsedSentence;
 import relex.feature.FeatureNode;
 import relex.feature.RelationCallback;
@@ -39,10 +36,6 @@ class OpenCogSchemeRel
 	// The sentence being examined.
 	private ParsedSentence parse;
 
-	// Map associating a feature-node to a unique ID string.
-	private ArrayList<String> word_list = null;
-	private HashMap<FeatureNode,String> id_map = null;
-
 	/* ----------------------------------------------------------- */
 	/* Constructors, and setters/getters for private members. */
 	// Constructor.
@@ -51,13 +44,9 @@ class OpenCogSchemeRel
 		parse = null;
 	}
 
-	public void setParse(ParsedSentence s,
-	                     ArrayList<String> wl,
-	                     HashMap<FeatureNode,String> im)
+	public void setParse(ParsedSentence s)
 	{
 		parse = s;
-		word_list = wl;
-		id_map = im;
 	}
 
 	/* ----------------------------------------------------------- */
@@ -85,7 +74,7 @@ class OpenCogSchemeRel
 			String value = attr.getValue();
 
 			outstr += "; " + attrName + " (" + srcName + ", " + value + ")\n";
-			String guid = id_map.get(srcNode);
+			String guid = srcNode.get("nameSource").get("uuid").getValue();
 
 			// Flags are assumed to be true, so value is the flag name.
 			if (attrName.endsWith("-FLAG"))
@@ -120,8 +109,8 @@ class OpenCogSchemeRel
 			if (tgtName == null) return false;
 
 			outstr += "; " + relName + " (" + srcName + ", " + tgtName + ") \n";
-			String src_guid = id_map.get(srcNode);
-			String tgt_guid = id_map.get(tgtNode);
+			String src_guid = srcNode.get("nameSource").get("uuid").getValue();
+			String tgt_guid = tgtNode.get("nameSource").get("uuid").getValue();
 
 			outstr += "(EvaluationLink (stv 1.0 1.0)\n";
 			outstr += "   (DefinedLinguisticRelationshipNode \"" + relName + "\")\n";
@@ -174,8 +163,7 @@ class OpenCogSchemeRel
 
 				// Remember the word-to guid map; we'll need it for
 				// printing relations, and printing frames,
-				String guid_word = word_list.get(word_index);
-				id_map.put(refNode, guid_word);
+				String guid_word = fn.get("uuid").getValue();
 
 				// The word instance, and its associated lemma form
 				refs += "(LemmaLink (stv 1.0 1.0)\n";
