@@ -22,8 +22,15 @@ import relex.ParsedSentence;
 import relex.feature.FeatureNode;
 
 /**
+ * XXX This class is obsolete. The format that it generates is no
+ * longer compatible with what various OpenCog mind-agents are
+ * expecting as input. Use the Scheme export format instead.
+ *
+ * (Note also: the scheme importer is twice as fast as the XML
+ * importer!) The scheme input format is human readable!
+ *
  * The OpenCogXML object outputs a ParsedSentence in the Novamente
- * OpenCog-style XML format. The actual format used, and its rational,
+ * OpenCog-style XML format. The actual format used, and its rationale,
  * is described in greater detail in the README file in the opencog
  * source code directory src/nlp/wsd/README.
  *
@@ -35,15 +42,15 @@ import relex.feature.FeatureNode;
 public class OpenCogXML
 {
 	private HashMap<FeatureNode,String> id_map = null;
-	private RelXML rel_xml;
-	private FrameXML frame_xml;
+	private OpenCogXMLRel rel_xml;
+	private OpenCogXMLFrame frame_xml;
 
 	/* -------------------------------------------------------------------- */
 	/* Constructors, and setters/getters for private members. */
 	public OpenCogXML()
 	{
-		rel_xml = new RelXML();
-		frame_xml = new FrameXML();
+		rel_xml = new OpenCogXMLRel();
+		frame_xml = new OpenCogXMLFrame();
 	}
 
 	public void setParse(ParsedSentence sent)
