@@ -20,7 +20,6 @@ import java.util.HashMap;
 import relex.ParsedSentence;
 import relex.feature.FeatureNode;
 import relex.feature.FeatureNodeCallback;
-import relex.feature.FeatureForeach;
 
 /**
  * A ParseView object displays a ParsedSentence in either
@@ -28,8 +27,6 @@ import relex.feature.FeatureForeach;
  * As the same sentence can have multiple parses, this
  * class only displays a single, particular parse.
  *
- * This class is a part of the Cerego graph visualization project.
- *
  * The name of this class is likely to change to some better name,
  * suggestions welcome.
  *
@@ -225,12 +222,12 @@ public class ParseView {
 		rel_implode = new HashMap<String,HashMap<String,String>>();
 
 		// Implodables
-		declRel("_appo",         "appo",         true);
+		declRel("_appo",         "appostive",    true);
 		declRel("_obj",          "object",       true);
-		declRel("_obj2",         "ind-obj",      true);
+		declRel("_iobj",         "ind-obj",      true);
 		declRel("_subj",         "subject",      true);
-		declRel("_prepObj",      "prep-object",  true);
-		declRel("_prepSubj",     "prep-subject", true);
+		declRel("_pobj",         "prep-object",  true);
+		declRel("_psubj",        "prep-subject", true);
 
 		// Non-Implodables
 		declRel("_to-do",         "action",         false);
@@ -298,10 +295,10 @@ public class ParseView {
 		// Implodables
 		declRel("_appo",         "Appositive",           true);
 		declRel("_obj",          "Object",               true);
-		declRel("_obj2",         "IndirectObject",       true);
+		declRel("_iobj",         "IndirectObject",       true);
 		declRel("_subj",         "Subject",              true);
-		declRel("_prepObj",      "PrepositionalObject",  true);
-		declRel("_prepSubj",     "PrepositionalSubject", true);
+		declRel("_pobj",         "PrepositionalObject",  true);
+		declRel("_psubj",        "PrepositionalSubject", true);
 
 		// Non-Implodables
 		declRel("_to-do",         "Action",         false);
@@ -456,7 +453,7 @@ public class ParseView {
 	{
 		id_map = new HashMap<String,String>();
 		string_id = 2001;
-		FeatureForeach.foreach(sent.getLeft(), new findIDs());
+		sent.foreach(new findIDs());
 
 		String outstr = "   <relex_words>\n";
 
@@ -546,7 +543,7 @@ public class ParseView {
 		relview.setIndex(3001);
 		String outstr = rel_markup_start;
 		prtRelation prt = new prtRelation();
-		FeatureForeach.foreach(sent.getLeft(), prt);
+		sent.foreach(prt);
 		outstr += prt.outstr;
 		outstr += rel_markup_end;
 		return outstr;
